Internal API of Simul
=====================

.. seealso::

   Documentation on  :class:`fluidsim:fluidsim_core.solver.SimulCore` which is the base class for :class:`snek5000.solvers.base.SimulNek`.

.. automethod:: snek5000.solvers.base.SimulNek._set_internal_sections
.. automethod:: snek5000.solvers.base.SimulNek._complete_params_with_default

Internal API of InfoSolver
==========================

.. seealso::

   Documentation on  :class:`fluidsim:fluidsim_core.info.InfoSolverCore` which is the base class for :class:`snek5000.info.InfoSolverNek`.

.. automethod:: snek5000.info.InfoSolverNek._init_root
